embassy-net-esp-hosted

Crates

git

Versions

default

Flavors

Security

Enum Security 

pub enum Security {
Show 19 variants Open, Wep, WpaPsk, Wpa2Psk, WpaWpa2Psk, Enterprise, Wpa2Enterprise, Wpa3Psk, Wpa2Wpa3Psk, WapiPsk, Owe, Wpa3Ent192, Wpa3ExtPsk, Wpa3ExtPskMixedMode, Dpp, Wpa3Enterprise, Wpa2Wpa3Enterprise, WpaEnterprise, Unknown(i32),
}
WiFi security mode.

Variants



Open

Open network.



Wep

WEP.



WpaPsk

WPA-PSK.



Wpa2Psk

WPA2-PSK.



WpaWpa2Psk

WPA/WPA2-PSK.



Enterprise

Wi-Fi EAP security, treated the same as Wpa2Enterprise



Wpa2Enterprise

Wi-Fi EAP security, Authenticate mode : WPA2-Enterprise security



Wpa3Psk

WPA3-PSK.



Wpa2Wpa3Psk

WPA2/WPA3-PSK.



WapiPsk

WAPI-PSK.



Owe

Opportunistic Wireless Encryption.



Wpa3Ent192

WPA‑EAP‑Suite‑B‑192.



Wpa3ExtPsk

This authentication mode will yield same result as Wpa3Psk and not recommended to be used. It will be deprecated in future, please use Wpa3Psk instead.



Wpa3ExtPskMixedMode

This authentication mode will yield same result as Wpa3Psk and not recommended to be used. It will be deprecated in future, please use Wpa3Psk instead.



Dpp

Device Provisioning Protocol.



Wpa3Enterprise

WPA3-Enterprise Only Mode.



Wpa2Wpa3Enterprise

WPA3-Enterprise Transition Mode.



WpaEnterprise

WPA-Enterprise security.



Unknown(i32)

Unknown security mode reported by firmware.