pub async fn new<'a, I, OUT>(
state: &'a mut State,
iface: I,
reset: OUT,
) -> HostedResources<'a, I, OUT>Expand description
Create a new esp-hosted driver.
Returns a device handle for interfacing with embassy-net, a control handle for interacting with the driver, and a runner for communicating with the WiFi device.