embassy-net-esp-hosted

Crates

git

Versions

default

Flavors

Control

Struct Control 

pub struct Control<'a> { /* private fields */ }
Handle for managing the network and WiFI state.

Implementations

Source

impl<'a> Control<'a>

pub async fn init(&mut self) -> Result<(), Error>

Initialize device.

pub fn hardware_address(&self) -> HardwareAddress

Get hardware address

Use after init method successful execution

This method may be used to update interface hardware address if you have initialized network stack before this device

use embassy_net::wire::HardwareAddress;
iface.set_hardware_addr(HardwareAddress::from_driver(ctl.hardware_address()).unwrap());
pub fn reset(&self)

Reset ESP and initialzation state

init should be executed again after reset

pub async fn get_status(&mut self) -> Result<Status, Error>

Get the current status.

pub async fn scan<const N: usize>( &mut self, result: &mut Vec<Network, N>, ) -> Result<(), Error>

Scan for available networks.

pub async fn connect(&mut self, ssid: &str, password: &str) -> Result<(), Error>

Connect to the network identified by ssid using the provided password.

pub async fn disconnect(&mut self) -> Result<(), Error>

Disconnect from any currently connected network.

pub async fn get_fw_version(&mut self) -> Result<FwVersion, Error>

Return the firmware version of the device.

pub async fn ota_begin(&mut self) -> Result<(), Error>

Initiate a firmware update.

pub async fn ota_write(&mut self, data: &[u8]) -> Result<(), Error>

Write slice of firmware to a device.

ota_begin must be called first.

The slice is split into chunks that can be sent across the ioctl protocol to the wifi adapter.

pub async fn ota_end(&mut self) -> Result<(), Error>

End the OTA session.

ota_begin must be called first.

NOTE: Will reset the wifi adapter after 5 seconds.